summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/tools/linguist/linguist
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/tools/linguist/linguist')
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.cpp88
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.h6
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_de.ts12
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_fr.ts12
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/listviews.cpp6
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/msgedit.cpp2
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/phrase.cpp10
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/simtexth.cpp2
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.cpp102
-rw-r--r--experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.h20
10 files changed, 130 insertions, 130 deletions
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.cpp b/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.cpp
index 6dc876cc6..fe8129a16 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.cpp
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.cpp
@@ -46,60 +46,60 @@
#include <tqpushbutton.h>
#include <tqwhatsthis.h>
-FindDialog::FindDialog( bool tqreplace, TQWidget *tqparent, const char *name,
+FindDialog::FindDialog( bool replace, TQWidget *tqparent, const char *name,
bool modal )
: TQDialog( tqparent, name, modal )
{
sourceText = 0;
- led = new TQLineEdit( this, "tqfind line edit" );
- TQLabel *tqfindWhat = new TQLabel( led, tr("Fi&nd what:"), this, "tqfind what" );
- TQLabel *tqreplaceWith = 0;
- TQPushButton *tqfindNxt = new TQPushButton( tr("&Find Next"), this,
- "tqfind next" );
- tqfindNxt->setDefault( TRUE );
- connect( tqfindNxt, TQT_SIGNAL(clicked()), this, TQT_SLOT(emitFindNext()) );
- TQPushButton *cancel = new TQPushButton( tr("Cancel"), this, "cancel tqfind" );
+ led = new TQLineEdit( this, "find line edit" );
+ TQLabel *findWhat = new TQLabel( led, tr("Fi&nd what:"), this, "find what" );
+ TQLabel *replaceWith = 0;
+ TQPushButton *findNxt = new TQPushButton( tr("&Find Next"), this,
+ "find next" );
+ findNxt->setDefault( TRUE );
+ connect( findNxt, TQT_SIGNAL(clicked()), this, TQT_SLOT(emitFindNext()) );
+ TQPushButton *cancel = new TQPushButton( tr("Cancel"), this, "cancel find" );
connect( cancel, TQT_SIGNAL(clicked()), this, TQT_SLOT(reject()) );
- TQVBoxLayout *bl = new TQVBoxLayout( 6, "tqfind button tqlayout" );
- bl->addWidget( tqfindNxt );
+ TQVBoxLayout *bl = new TQVBoxLayout( 6, "find button tqlayout" );
+ bl->addWidget( findNxt );
- matchCase = new TQCheckBox( tr("&Match case"), this, "tqfind match case" );
+ matchCase = new TQCheckBox( tr("&Match case"), this, "find match case" );
matchCase->setChecked( FALSE );
- if ( tqreplace ) {
- TQWhatsThis::add( this, tr("This window allows you to search and tqreplace"
+ if ( replace ) {
+ TQWhatsThis::add( this, tr("This window allows you to search and replace"
" some text in the translations.") );
- red = new TQLineEdit( this, "tqreplace line edit" );
- tqreplaceWith = new TQLabel( red, tr("Replace &with:"), this,
- "tqreplace with" );
+ red = new TQLineEdit( this, "replace line edit" );
+ replaceWith = new TQLabel( red, tr("Replace &with:"), this,
+ "replace with" );
setTabOrder( led, red );
- TQPushButton *tqreplace = new TQPushButton( tr("&Replace"), this,
- "tqreplace" );
- connect( tqreplace, TQT_SIGNAL(clicked()), this, TQT_SLOT(emitReplace()) );
- TQPushButton *tqreplaceAll = new TQPushButton( tr("Replace &All"), this,
- "tqreplace all" );
- connect( tqreplaceAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(emitReplaceAll()) );
- setTabOrder( tqfindNxt, tqreplace );
- setTabOrder( tqreplace, tqreplaceAll );
- setTabOrder( tqreplaceAll, cancel );
-
- TQWhatsThis::add( tqreplace, tr("Click here to tqreplace the next occurrence"
+ TQPushButton *replace = new TQPushButton( tr("&Replace"), this,
+ "replace" );
+ connect( replace, TQT_SIGNAL(clicked()), this, TQT_SLOT(emitReplace()) );
+ TQPushButton *replaceAll = new TQPushButton( tr("Replace &All"), this,
+ "replace all" );
+ connect( replaceAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(emitReplaceAll()) );
+ setTabOrder( findNxt, replace );
+ setTabOrder( replace, replaceAll );
+ setTabOrder( replaceAll, cancel );
+
+ TQWhatsThis::add( replace, tr("Click here to replace the next occurrence"
" of the text you typed in.") );
- TQWhatsThis::add( tqreplaceAll, tr("Click here to tqreplace all occurrences"
+ TQWhatsThis::add( replaceAll, tr("Click here to replace all occurrences"
" of the text you typed in.") );
- bl->addWidget( tqreplace );
- bl->addWidget( tqreplaceAll );
+ bl->addWidget( replace );
+ bl->addWidget( replaceAll );
TQGridLayout *gl = new TQGridLayout( this, 4, 3, 11, 11,
- "tqfind outer tqlayout" );
- gl->addWidget( tqfindWhat, 0, 0 );
+ "find outer tqlayout" );
+ gl->addWidget( findWhat, 0, 0 );
gl->addWidget( led, 0, 1 );
- gl->addWidget( tqreplaceWith, 1, 0 );
+ gl->addWidget( replaceWith, 1, 0 );
gl->addWidget( red, 1, 1 );
gl->addMultiCellWidget( matchCase, 2, 2, 0, 1 );
gl->addMultiCell( bl, 0, 3, 3, 3 );
@@ -108,12 +108,12 @@ FindDialog::FindDialog( bool tqreplace, TQWidget *tqparent, const char *name,
" text in the translation source file.") );
sourceText = new TQCheckBox( tr("&Source texts"), this,
- "tqfind in source texts" );
+ "find in source texts" );
sourceText->setChecked( TRUE );
translations = new TQCheckBox( tr("&Translations"), this,
- "tqfind in translations" );
+ "find in translations" );
translations->setChecked( TRUE );
- comments = new TQCheckBox( tr("&Comments"), this, "tqfind in comments" );
+ comments = new TQCheckBox( tr("&Comments"), this, "find in comments" );
comments->setChecked( TRUE );
TQWhatsThis::add( sourceText, tr("Source texts are searched when"
@@ -123,11 +123,11 @@ FindDialog::FindDialog( bool tqreplace, TQWidget *tqparent, const char *name,
TQWhatsThis::add( comments, tr("Comments and contexts are searched when"
" checked.") );
- TQVBoxLayout *cl = new TQVBoxLayout( 6, "tqfind checkbox tqlayout" );
+ TQVBoxLayout *cl = new TQVBoxLayout( 6, "find checkbox tqlayout" );
TQGridLayout *gl = new TQGridLayout( this, 3, 4, 11, 11,
- "tqfind outer tqlayout" );
- gl->addWidget( tqfindWhat, 0, 0 );
+ "find outer tqlayout" );
+ gl->addWidget( findWhat, 0, 0 );
gl->addMultiCellWidget( led, 0, 0, 1, 2 );
gl->addWidget( matchCase, 1, 2 );
gl->addMultiCell( bl, 0, 2, 3, 3 );
@@ -147,7 +147,7 @@ FindDialog::FindDialog( bool tqreplace, TQWidget *tqparent, const char *name,
TQWhatsThis::add( matchCase, tr("Texts such as 'TeX' and 'tex' are"
" considered as different when checked.") );
- TQWhatsThis::add( tqfindNxt, tr("Click here to tqfind the next occurrence of the"
+ TQWhatsThis::add( findNxt, tr("Click here to find the next occurrence of the"
" text you typed in.") );
TQWhatsThis::add( cancel, tr("Click here to close this window.") );
@@ -169,15 +169,15 @@ void FindDialog::emitFindNext()
( comments->isChecked() ? Comments : 0 );
else
where = Translations;
- emit tqfindNext( led->text(), where, matchCase->isChecked() );
+ emit findNext( led->text(), where, matchCase->isChecked() );
}
void FindDialog::emitReplace()
{
- emit tqreplace( led->text(), red->text(), matchCase->isChecked(), FALSE );
+ emit replace( led->text(), red->text(), matchCase->isChecked(), FALSE );
}
void FindDialog::emitReplaceAll()
{
- emit tqreplace( led->text(), red->text(), matchCase->isChecked(), TRUE );
+ emit replace( led->text(), red->text(), matchCase->isChecked(), TRUE );
}
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.h b/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.h
index 2cf8e4307..47d0ec53c 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.h
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/finddialog.h
@@ -46,11 +46,11 @@ class FindDialog : public TQDialog
public:
enum { SourceText = 0x1, Translations = 0x2, Comments = 0x4 };
- FindDialog( bool tqreplace, TQWidget *tqparent = 0, const char *name = 0, bool modal = FALSE );
+ FindDialog( bool replace, TQWidget *tqparent = 0, const char *name = 0, bool modal = FALSE );
Q_SIGNALS:
- void tqfindNext( const TQString& text, int where, bool matchCase );
- void tqreplace( const TQString& before, const TQString& after, bool matchCase, bool all );
+ void findNext( const TQString& text, int where, bool matchCase );
+ void replace( const TQString& before, const TQString& after, bool matchCase, bool all );
private Q_SLOTS:
void emitFindNext();
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_de.ts b/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_de.ts
index 31e6737e8..2c7708be6 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_de.ts
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_de.ts
@@ -50,7 +50,7 @@
<translation type="unfinished"></translation>
</message>
<message>
- <source>This window allows you to search and tqreplace some text in the translations.</source>
+ <source>This window allows you to search and replace some text in the translations.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -66,11 +66,11 @@
<translation type="unfinished"></translation>
</message>
<message>
- <source>Click here to tqreplace the next occurrence of the text you typed in.</source>
+ <source>Click here to replace the next occurrence of the text you typed in.</source>
<translation type="unfinished"></translation>
</message>
<message>
- <source>Click here to tqreplace all occurrences of the text you typed in.</source>
+ <source>Click here to replace all occurrences of the text you typed in.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -110,7 +110,7 @@
<translation type="unfinished"></translation>
</message>
<message>
- <source>Click here to tqfind the next occurrence of the text you typed in.</source>
+ <source>Click here to find the next occurrence of the text you typed in.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -413,7 +413,7 @@ All files (*)</source>
<translation type="unfinished"></translation>
</message>
<message>
- <source>Cannot tqfind the string &apos;%1&apos;.</source>
+ <source>Cannot find the string &apos;%1&apos;.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -774,7 +774,7 @@ All files (*)</source>
<translation type="unfinished"></translation>
</message>
<message>
- <source>Search for some text in the translation source file and tqreplace it by another text.</source>
+ <source>Search for some text in the translation source file and replace it by another text.</source>
<translation type="unfinished"></translation>
</message>
<message>
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_fr.ts b/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_fr.ts
index 31e6737e8..2c7708be6 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_fr.ts
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/linguist_fr.ts
@@ -50,7 +50,7 @@
<translation type="unfinished"></translation>
</message>
<message>
- <source>This window allows you to search and tqreplace some text in the translations.</source>
+ <source>This window allows you to search and replace some text in the translations.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -66,11 +66,11 @@
<translation type="unfinished"></translation>
</message>
<message>
- <source>Click here to tqreplace the next occurrence of the text you typed in.</source>
+ <source>Click here to replace the next occurrence of the text you typed in.</source>
<translation type="unfinished"></translation>
</message>
<message>
- <source>Click here to tqreplace all occurrences of the text you typed in.</source>
+ <source>Click here to replace all occurrences of the text you typed in.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -110,7 +110,7 @@
<translation type="unfinished"></translation>
</message>
<message>
- <source>Click here to tqfind the next occurrence of the text you typed in.</source>
+ <source>Click here to find the next occurrence of the text you typed in.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -413,7 +413,7 @@ All files (*)</source>
<translation type="unfinished"></translation>
</message>
<message>
- <source>Cannot tqfind the string &apos;%1&apos;.</source>
+ <source>Cannot find the string &apos;%1&apos;.</source>
<translation type="unfinished"></translation>
</message>
<message>
@@ -774,7 +774,7 @@ All files (*)</source>
<translation type="unfinished"></translation>
</message>
<message>
- <source>Search for some text in the translation source file and tqreplace it by another text.</source>
+ <source>Search for some text in the translation source file and replace it by another text.</source>
<translation type="unfinished"></translation>
</message>
<message>
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/listviews.cpp b/experimental/tqtinterface/qt4/tools/linguist/linguist/listviews.cpp
index 5c298b2eb..5c3c747b8 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/listviews.cpp
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/listviews.cpp
@@ -109,12 +109,12 @@ int LVI::compare( TQListViewItem *other, int column, bool ascending ) const
TQString thisKey = key( column, ascending );
TQString otherKey = other->key( column, ascending );
- if ( thisKey.tqcontains('&') || otherKey.tqcontains('&') ) {
+ if ( thisKey.contains('&') || otherKey.contains('&') ) {
TQString nicerThisKey = thisKey;
TQString nicerOtherKey = otherKey;
- nicerThisKey.tqreplace( "&", "" );
- nicerOtherKey.tqreplace( "&", "" );
+ nicerThisKey.replace( "&", "" );
+ nicerOtherKey.replace( "&", "" );
int delta = nicerThisKey.localeAwareCompare( nicerOtherKey );
if ( delta != 0 )
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/msgedit.cpp b/experimental/tqtinterface/qt4/tools/linguist/linguist/msgedit.cpp
index 744cd16ab..5e2987550 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/msgedit.cpp
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/msgedit.cpp
@@ -195,7 +195,7 @@ void ShadowWidget::paintEvent( TQPaintEvent * e )
/*
EditorPage class impl.
- A frame that tqcontains the source text, translated text and any
+ A frame that contains the source text, translated text and any
source code comments and hints.
*/
EditorPage::EditorPage( TQWidget * tqparent, const char * name )
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/phrase.cpp b/experimental/tqtinterface/qt4/tools/linguist/linguist/phrase.cpp
index 95b4fc2e7..c38e9e00a 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/phrase.cpp
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/phrase.cpp
@@ -44,11 +44,11 @@
static TQString protect( const TQString& str )
{
TQString p = str;
- p.tqreplace( "&", "&amp;" );
- p.tqreplace( "\"", "&quot;" );
- p.tqreplace( ">", "&gt;" );
- p.tqreplace( "<", "&lt;" );
- p.tqreplace( "'", "&apos;" );
+ p.replace( "&", "&amp;" );
+ p.replace( "\"", "&quot;" );
+ p.replace( ">", "&gt;" );
+ p.replace( "<", "&lt;" );
+ p.replace( "'", "&apos;" );
return p;
}
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/simtexth.cpp b/experimental/tqtinterface/qt4/tools/linguist/linguist/simtexth.cpp
index 2d139651e..9d78cf72b 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/simtexth.cpp
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/simtexth.cpp
@@ -206,7 +206,7 @@ CandidateList similarTextHeuristicCandidates( const MetaTranslator *tor,
int delta = TQABS( (int) s.length() - targetLen );
/*
- Here is the score formula. A comment above tqcontains a
+ Here is the score formula. A comment above contains a
discussion on a similar (but simpler) formula.
*/
int score = ( (intersection(cm, cmTarget).worth() + 1) << 10 ) /
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.h b/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.h
index 3e695345c..142fde2b3 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.h
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.h
@@ -96,9 +96,9 @@ private Q_SLOTS:
void saveAs();
void release();
void print();
- void tqfind();
- void tqfindAgain();
- void tqreplace();
+ void find();
+ void findAgain();
+ void replace();
void newPhraseBook();
void openPhraseBook();
void closePhraseBook( int id );
@@ -119,7 +119,7 @@ private Q_SLOTS:
void toggleFinished( TQListViewItem *item, const TQPoint& p, int column );
void prevUnfinished();
void nextUnfinished();
- void tqfindNext( const TQString& text, int where, bool matchCase );
+ void findNext( const TQString& text, int where, bool matchCase );
void revalidate();
void toggleGuessing();
void focusSourceList();
@@ -179,9 +179,9 @@ private:
FindDialog *f;
FindDialog *h;
- TQString tqfindText;
- int tqfindWhere;
- bool tqfindMatchCase;
+ TQString findText;
+ int findWhere;
+ bool findMatchCase;
int foundItem;
TQListViewItem *foundScope;
int foundWhere;
@@ -207,9 +207,9 @@ private:
Action *copyAct;
Action *pasteAct;
Action *selectAllAct;
- Action *tqfindAct;
- Action *tqfindAgainAct;
- Action *tqreplaceAct;
+ Action *findAct;
+ Action *findAgainAct;
+ Action *replaceAct;
Action *newPhraseBookAct;
Action *openPhraseBookAct;
Action *acceleratorsAct;
diff --git a/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.cpp b/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.cpp
index 8ebc932a3..564845f1d 100644
--- a/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.cpp
+++ b/experimental/tqtinterface/qt4/tools/linguist/linguist/trwindow.cpp
@@ -290,12 +290,12 @@ TrWindow::TrWindow()
phraseBooks.setAutoDelete( TRUE );
- f = new FindDialog( FALSE, this, "tqfind", FALSE );
+ f = new FindDialog( FALSE, this, "find", FALSE );
f->setCaption( tqtr("TQt Linguist") );
- h = new FindDialog( TRUE, this, "tqreplace", FALSE );
+ h = new FindDialog( TRUE, this, "replace", FALSE );
h->setCaption( tqtr("TQt Linguist") );
- tqfindMatchCase = FALSE;
- tqfindWhere = 0;
+ findMatchCase = FALSE;
+ findWhere = 0;
foundItem = 0;
foundScope = 0;
foundWhere = 0;
@@ -320,8 +320,8 @@ TrWindow::TrWindow()
connect( me, TQT_SIGNAL(nextUnfinished()), this, TQT_SLOT(nextUnfinished()) );
connect( me, TQT_SIGNAL(focusSourceList()), this, TQT_SLOT(focusSourceList()) );
connect( me, TQT_SIGNAL(focusPhraseList()), this, TQT_SLOT(focusPhraseList()) );
- connect( f, TQT_SIGNAL(tqfindNext(const TQString&, int, bool)),
- this, TQT_SLOT(tqfindNext(const TQString&, int, bool)) );
+ connect( f, TQT_SIGNAL(findNext(const TQString&, int, bool)),
+ this, TQT_SLOT(findNext(const TQString&, int, bool)) );
TQWhatsThis::add( lv, tqtr("This panel lists the source contexts.") );
@@ -378,7 +378,7 @@ void TrWindow::openFile( const TQString& name )
srcCharsSpc = 0;
for ( it = all.begin(); it != all.end(); ++it ) {
tqApp->processEvents();
- ContextLVI *c = contexts.tqfind( TQString((*it).context()) );
+ ContextLVI *c = contexts.find( TQString((*it).context()) );
if ( c == 0 ) {
c = new ContextLVI( lv, tor.toUnicode((*it).context(),
(*it).utf8()) );
@@ -434,10 +434,10 @@ void TrWindow::openFile( const TQString& name )
foundWhere = 0;
foundOffset = 0;
if ( lv->childCount() > 0 ) {
- tqfindAct->setEnabled( TRUE );
- tqfindAgainAct->setEnabled( FALSE );
+ findAct->setEnabled( TRUE );
+ findAgainAct->setEnabled( FALSE );
#ifdef notyet
- tqreplaceAct->setEnabled( TRUE );
+ replaceAct->setEnabled( TRUE );
#endif
lv->setCurrentItem( lv->firstChild() );
}
@@ -493,7 +493,7 @@ void TrWindow::saveAs()
void TrWindow::release()
{
TQString newFilename = filename;
- newFilename.tqreplace( TQRegExp(".ts$"), "" );
+ newFilename.replace( TQRegExp(".ts$"), "" );
newFilename += TQString( ".qm" );
newFilename = TQFileDialog::getSaveFileName( newFilename,
@@ -580,7 +580,7 @@ void TrWindow::print()
}
}
-void TrWindow::tqfind()
+void TrWindow::find()
{
h->hide();
f->show();
@@ -588,7 +588,7 @@ void TrWindow::tqfind()
f->raise();
}
-void TrWindow::tqfindAgain()
+void TrWindow::findAgain()
{
int pass = 0;
int oldItemNo = itemToIndex( slv, slv->currentItem() );
@@ -685,13 +685,13 @@ void TrWindow::tqfindAgain()
slv->triggerUpdate();
tqApp->beep();
TQMessageBox::warning( this, tqtr("TQt Linguist"),
- TQString( tqtr("Cannot tqfind the string '%1'.") ).arg(tqfindText) );
+ TQString( tqtr("Cannot find the string '%1'.") ).arg(findText) );
foundItem = 0;
foundWhere = 0;
foundOffset = 0;
}
-void TrWindow::tqreplace()
+void TrWindow::replace()
{
f->hide();
h->show();
@@ -729,8 +729,8 @@ TQListViewItem * TrWindow::indexToItem( TQListView * view, int index )
bool TrWindow::searchItem( const TQString & searchWhat, TQListViewItem * j,
TQListViewItem * k )
{
- if ( (tqfindWhere & foundWhere) != 0 ) {
- foundOffset = searchWhat.tqfind( tqfindText, foundOffset, tqfindMatchCase );
+ if ( (findWhere & foundWhere) != 0 ) {
+ foundOffset = searchWhat.find( findText, foundOffset, findMatchCase );
if ( foundOffset >= 0 ) {
foundItem = itemToIndex( slv, k );
foundScope = j;
@@ -776,7 +776,7 @@ void TrWindow::openPhraseBook()
"All files (*)"),
this, "open_phrasebook",
tqtr("Open Phrase Book") );
- if ( !name.isEmpty() && !phraseBookNames.tqcontains(name) ) {
+ if ( !name.isEmpty() && !phraseBookNames.contains(name) ) {
if ( openPhraseBook(name) ) {
int n = (int)(phraseBooks.at( phraseBooks.count() - 1 )->count());
statusBar()->message( tqtr("%1 phrase(s) loaded.").arg(n),
@@ -958,7 +958,7 @@ void TrWindow::showNewScope( TQListViewItem *item )
// Make sure that we update the source text and translation text. Use the first message in the new scope.
setCurrentMessageItem(slv->firstChild());
// This must be explicitly called since the signal is not emitted if the context only tqcontains one item
showNewCurrent(slv->firstChild());
slv->viewport()->setUpdatesEnabled( upe );
slv->setUpdatesEnabled( upe );
@@ -1342,15 +1342,15 @@ void TrWindow::next()
}
-void TrWindow::tqfindNext( const TQString& text, int where, bool matchCase )
+void TrWindow::findNext( const TQString& text, int where, bool matchCase )
{
- tqfindText = text;
- if ( tqfindText.isEmpty() )
- tqfindText = TQString( "magicwordthatyoushouldavoid" );
- tqfindWhere = where;
- tqfindMatchCase = matchCase;
- tqfindAgainAct->setEnabled( TRUE );
- tqfindAgain();
+ findText = text;
+ if ( findText.isEmpty() )
+ findText = TQString( "magicwordthatyoushouldavoid" );
+ findWhere = where;
+ findMatchCase = matchCase;
+ findAgainAct->setEnabled( TRUE );
+ findAgain();
}
void TrWindow::revalidate()
@@ -1384,8 +1384,8 @@ void TrWindow::revalidate()
TQString TrWindow::friendlyString( const TQString& str )
{
TQString f = str.lower();
- f.tqreplace( TQRegExp(TQString("[.,:;!?()-]")), TQString(" ") );
- f.tqreplace( "&", TQString("") );
+ f.replace( TQRegExp(TQString("[.,:;!?()-]")), TQString(" ") );
+ f.replace( "&", TQString("") );
f = f.simplifyWhiteSpace();
f = f.lower();
return f;
@@ -1478,16 +1478,16 @@ void TrWindow::setupMenuBar()
TQString(), TQAccel::stringToKey(tqtr("Ctrl+A")) );
selectAllAct->setEnabled( FALSE );
editp->insertSeparator();
- tqfindAct = new Action( editp, tqtr("&Find..."), TQT_TQOBJECT(this), TQT_SLOT(tqfind()),
+ findAct = new Action( editp, tqtr("&Find..."), TQT_TQOBJECT(this), TQT_SLOT(find()),
"searchfind.png", TQAccel::stringToKey(tqtr("Ctrl+F")) );
- tqfindAct->setEnabled( FALSE );
- tqfindAgainAct = new Action( editp, tqtr("Find &Next"),
- TQT_TQOBJECT(this), TQT_SLOT(tqfindAgain()), TQString(), Qt::Key_F3 );
- tqfindAgainAct->setEnabled( FALSE );
+ findAct->setEnabled( FALSE );
+ findAgainAct = new Action( editp, tqtr("Find &Next"),
+ TQT_TQOBJECT(this), TQT_SLOT(findAgain()), TQString(), Qt::Key_F3 );
+ findAgainAct->setEnabled( FALSE );
#ifdef notyet
- tqreplaceAct = new Action( editp, tqtr("&Replace..."), TQT_TQOBJECT(this), TQT_SLOT(tqreplace()),
+ replaceAct = new Action( editp, tqtr("&Replace..."), TQT_TQOBJECT(this), TQT_SLOT(replace()),
TQAccel::stringToKey(tqtr("Ctrl+H")) );
- tqreplaceAct->setEnabled( FALSE );
+ replaceAct->setEnabled( FALSE );
#endif
// Translation menu
@@ -1591,12 +1591,12 @@ void TrWindow::setupMenuBar()
pasteAct->setWhatsThis( tqtr("Paste the clipboard text into the"
" translation.") );
selectAllAct->setWhatsThis( tqtr("Select the whole translation text.") );
- tqfindAct->setWhatsThis( tqtr("Search for some text in the translation "
+ findAct->setWhatsThis( tqtr("Search for some text in the translation "
"source file.") );
- tqfindAgainAct->setWhatsThis( tqtr("Continue the search where it was left.") );
+ findAgainAct->setWhatsThis( tqtr("Continue the search where it was left.") );
#ifdef notyet
- tqreplaceAct->setWhatsThis( tqtr("Search for some text in the translation"
- " source file and tqreplace it by another"
+ replaceAct->setWhatsThis( tqtr("Search for some text in the translation"
+ " source file and replace it by another"
" text.") );
#endif
@@ -1654,13 +1654,13 @@ void TrWindow::setupToolBars()
copyAct->addToToolbar( editt, tqtr("Copy") );
pasteAct->addToToolbar( editt, tqtr("Paste") );
editt->addSeparator();
- tqfindAct->addToToolbar( editt, tqtr("Find") );
+ findAct->addToToolbar( editt, tqtr("Find") );
#ifdef notyet
- tqreplaceAct->addToToolbar( editt, tqtr("Replace") );
+ replaceAct->addToToolbar( editt, tqtr("Replace") );
#endif
// beginFromSourceAct->addToToolbar( translationst,
- // tqtr("Begin from Source"), "searchtqfind" );
+ // tqtr("Begin from Source"), "searchfind" );
prevAct->addToToolbar( translationst, tqtr("Prev") );
nextAct->addToToolbar( translationst, tqtr("Next") );
prevUnfinishedAct->addToToolbar( translationst, tqtr("Prev Unfinished") );
@@ -1718,7 +1718,7 @@ bool TrWindow::openPhraseBook( const TQString& name )
bool TrWindow::savePhraseBook( TQString& name, const PhraseBook& pb )
{
- if ( !name.tqcontains( ".qph" ) && !name.tqcontains(".") )
+ if ( !name.contains( ".qph" ) && !name.contains(".") )
name += ".qph";
if ( !pb.save(name) ) {
@@ -1754,7 +1754,7 @@ void TrWindow::updatePhraseDict()
TQString f = friendlyString( (*p).source() );
if ( f.length() > 0 ) {
f = TQStringList::split( TQChar(' '), f ).first();
- ent = phraseDict.tqfind( f );
+ ent = phraseDict.find( f );
if ( ent == 0 ) {
ent = new PhraseBook;
phraseDict.insert( f, ent );
@@ -1776,10 +1776,10 @@ PhraseBook TrWindow::getPhrases( const TQString& source )
PhraseBook::Iterator p;
for ( w = lookupWords.begin(); w != lookupWords.end(); ++w ) {
- PhraseBook *ent = phraseDict.tqfind( *w );
+ PhraseBook *ent = phraseDict.find( *w );
if ( ent != 0 ) {
for ( p = ent->begin(); p != ent->end(); ++p ) {
- if ( f.tqfind(friendlyString((*p).source())) >= 0 )
+ if ( f.find(friendlyString((*p).source())) >= 0 )
phrases.append( *p );
}
}
@@ -1822,11 +1822,11 @@ bool TrWindow::danger( const TQString& source, const TQString& translation,
PhraseBook::Iterator p;
for ( w = lookupWords.begin(); w != lookupWords.end(); ++w ) {
- PhraseBook *ent = phraseDict.tqfind( *w );
+ PhraseBook *ent = phraseDict.find( *w );
if ( ent != 0 ) {
for ( p = ent->begin(); p != ent->end(); ++p ) {
- if ( fsource.tqfind(friendlyString((*p).source())) < 0 ||
- ftranslation.tqfind(friendlyString((*p).target())) >= 0 )
+ if ( fsource.find(friendlyString((*p).source())) < 0 ||
+ ftranslation.find(friendlyString((*p).target())) >= 0 )
break;
}
if ( p == ent->end() ) {
@@ -1977,7 +1977,7 @@ void TrWindow::recentFileActivated( int id )
void TrWindow::addRecentlyOpenedFile( const TQString &fn, TQStringList &lst )
{
- if ( lst.tqfind( fn ) != lst.end() )
+ if ( lst.find( fn ) != lst.end() )
return;
if ( lst.count() >= 10 )
lst.remove( lst.begin() );
@@ -958,7 +958,7 @@ void TrWindow::showNewScope( TQListViewItem *item )
// Make sure that we update the source text and translation text. Use the first message in the new scope.
setCurrentMessageItem(slv->firstChild());
- // This must be explicitly called since the signal is not emitted if the context only tqcontains one item
+ // This must be explicitly called since the signal is not emitted if the context only contains one item
showNewCurrent(slv->firstChild());
slv->viewport()->setUpdatesEnabled( upe );